
library(tidyverse)
library(readxl)
tsActuary = read_excel("time statistics.xlsx")

backupName = names(tsActuary)

names(tsActuary) = c('No',"Time","Duration","Source","Details","IP","Location","Area","WorkingArea","Area2","Level","WorkingHours")



library(shiny)
library(bslib)
library(ggplot2)
library(ggthemes)
library(showtext)

# counts
hisplot = ggplot(data.frame(tsActuary), aes(x=WorkingHours)) +
  geom_bar()

hisplot <- renderPlot({
  ggplot(data.frame(tsActuary), aes(x=WorkingHours)) +
    geom_bar()
})

ui <- fluidPage(
  theme = bs_theme(version = 4, bootswatch = "dark"),
  titlePanel("Working Hours Survey for Actuaries"),
  navbarPage(
    "Navigation",
    tabPanel("Statistics for Survey Joiners",
             mainPanel( tabsetPanel(type = "tabs",
                                    tabPanel("Location Summary", plotOutput("Locationsummary",width = "600px", height = "600px")),
                                    tabPanel("Industry Summary", plotOutput("Industrysummary",width = "600px", height = "600px")),
                                    tabPanel("Working Aera Summary", plotOutput("WorkingAreasummary",width = "600px", height = "600px")),
                                    tabPanel("Pricing or Valuation Summary", plotOutput("PorVsummary",width = "600px", height = "600px")),
                                    tabPanel("Current Level Summary", plotOutput("CLsummary",width = "600px", height = "600px"))
             ))),
    tabPanel("Survey Result DashBoard",
             sidebarLayout(
               sidebarPanel(selectInput("countryInput", "Country or Region",
                                        choices = c("All", unique(tsActuary$Location))),
                            selectInput("AreaInput", "Industry",
                                        choices = c("All", unique(tsActuary$Area))),
                            selectInput("WorkingAreaInput", "Working Aera",
                                        choices = c("All", unique(tsActuary$WorkingArea))),
                            selectInput("Area2Input", "Pricing or Valuation",
                                        choices = c("All", unique(tsActuary$Area2))),
                            selectInput("LevelInput", "Current Level",
                                        choices = c("All", unique(tsActuary$Level)))),
               mainPanel( tabsetPanel(type = "tabs",
                                      tabPanel("Plot", plotOutput("hisplot")),
                                      #tabPanel("Summary", verbatimTextOutput("summary")),
                                      tabPanel("Table", tableOutput("results")))
               ))
  )
  )
)


server <- function(input, output) {
  #bs_themer()
  filtered <- reactive({
    filtered = tsActuary
    if(input$countryInput != "All")(
      filtered <-
        filtered %>%
        filter(
          Location == input$countryInput
        )
    )
    if(input$AreaInput != "All")(
      filtered <-
        filtered %>%
        filter(
          Area == input$AreaInput
        )
    )
    if(input$AreaInput != "All")(
      filtered <-
        filtered %>%
        filter(
          Area == input$AreaInput
        )
    )
    if(input$WorkingAreaInput != "All")(
      filtered <-
        filtered %>%
        filter(
          WorkingArea == input$WorkingAreaInput
        )
    )
    if(input$Area2Input != "All")(
      filtered <-
        filtered %>%
        filter(
          Area2 == input$Area2Input
        )
    )
    if(input$LevelInput != "All")(
      filtered <-
        filtered %>%
        filter(
          Level == input$LevelInput
        )
    )
    filtered
  })
  output$hisplot <- renderPlot({
    showtext.begin()
    g = ggplot(data.frame(filtered()), aes(x=WorkingHours,fill=Level)) +
      geom_bar()+ theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue")
    print(g)
    showtext.end()
  })
  output$results <- renderTable({
    table(filtered()$WorkingHours)
  })
  output$Locationsummary <- renderPlot({
    showtext.begin()
    g = ggplot(
      data.frame(table(tsActuary$Location)),aes(x="",y=Freq,fill=Var1)) +
      geom_bar(stat='identity',color="black")+
      geom_label(aes(label = Freq),color = "white",size=5,
                position = position_stack(vjust = 0.5),show.legend = FALSE)+ 
      coord_polar(theta="y") +
       theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue")
    print(g)
    showtext.end()
  })
  output$Industrysummary <- renderPlot({
    showtext.begin()
    g = ggplot(
      data.frame(table(tsActuary$Area)),aes(x="",y=Freq,fill=Var1)) +
      geom_bar(stat='identity',color="black")+
      geom_label(aes(label = Freq),color = "white",size=5,
                 position = position_stack(vjust = 0.5),show.legend = FALSE)+ coord_polar(theta="y") +
      theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue")
    print(g)
    showtext.end()
  })
  output$WorkingAreasummary <- renderPlot({
    showtext.begin()
    g = ggplot(
      data.frame(table(tsActuary$WorkingArea)),aes(x="",y=Freq,fill=Var1)) +
      geom_bar(stat='identity',color="black")+
      geom_label(aes(label = Freq),color = "white",size=5,
                 position = position_stack(vjust = 0.5),show.legend = FALSE)+ coord_polar(theta="y") +
      theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue")
    print(g)
    showtext.end()
  })
  output$PorVsummary <- renderPlot({
    showtext.begin()
    g = ggplot(
      data.frame(table(tsActuary$Area2)),aes(x="",y=Freq,fill=Var1)) +
      geom_bar(stat='identity',color="black")+
      geom_label(aes(label = Freq),color = "white",size=5,
                 position = position_stack(vjust = 0.5),show.legend = FALSE)+ coord_polar(theta="y") +
      theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue") 
    print(g)
    showtext.end()
  })
  output$CLsummary <- renderPlot({
    showtext.begin()
    g = ggplot(
      data.frame(table(tsActuary$Level)),aes(x="",y=Freq,fill=Var1)) +
      geom_bar(stat='identity',color="black")+
      geom_label(aes(label = Freq),color = "white",size=5,
                 position = position_stack(vjust = 0.5),show.legend = FALSE)+ coord_polar(theta="y") +
      theme_solarized_2(light = FALSE,base_family ="wqy-microhei") +
      scale_colour_solarized("blue")
    print(g)
    showtext.end()
  })
}

shinyApp(ui = ui, server = server)